aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/public/Util.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/public/Util.php b/lib/public/Util.php
index 4cee9addf10..a7cfdb4d6e4 100644
--- a/lib/public/Util.php
+++ b/lib/public/Util.php
@@ -310,7 +310,8 @@ class Util {
return $defaultEmailAddress;
}
- // in case we cannot build a valid email address from the hostname let's fallback to 'localhost.localdomain'
+ // in case we cannot build a valid email address from the hostname we log an error and fallback to 'localhost.localdomain' for now
+ \OCP\Server::get(LoggerInterface::class)->error('Unable to determine default email address ("mail_from_address" may be wrong). Using ' . $user_part . '@localhost.localdomain for the time being.');
return $user_part.'@localhost.localdomain';
}